{
  description = "headscale";

  inputs = {
    nixpkgs = {
      url = "nixpkgs/nixos-unstable";
    };
    flake-utils = {
      url = "github:numtide/flake-utils";
    };
  };

  outputs = { self, nixpkgs, flake-utils }@inputs:
    flake-utils.lib.eachDefaultSystem
      (system:
        let
          pkgs = import nixpkgs {
            inherit system;
          };
        in
        {
          packages = {
            headscale =
              let
                pname = "headscale";
                version = "0.18.0";
              in
              pkgs.buildGoModule {
                inherit pname version;

                src = pkgs.fetchFromGitHub {
                  owner = "juanfont";
                  repo = "headscale";
                  rev = "v${version}";
                  sha256 = "sha256-0viXsBRCiaxBTTKXJngSov5M7toscQUOdXDTr1l0U3I=";
                };

                vendorSha256 = "sha256-SuKT+b8g6xEK15ry2IAmpS/vwDG+zJqK9nfsWpHNXuU=";

                tags = [
                  "ts2019"
                ];

                ldflags = [
                  "-s"
                  "-w"
                  "-X github.com/juanfont/headscale/cmd/headscale/cli.Version=v${version}"
                ];

                checkFlags = [
                  "-short"
                ];

                nativeBuildInputs = [
                  pkgs.installShellFiles
                ];

                postInstall = ''
                  installShellCompletion --cmd headscale \
                    --bash <($out/bin/headscale completion bash) \
                    --fish <($out/bin/headscale completion fish) \
                    --zsh <($out/bin/headscale completion zsh)
                '';

                meta = with pkgs.lib; {
                  homepage = "https://github.com/juanfont/headscale";
                  description = "An open source, self-hosted implementation of the Tailscale control server";
                  longDescription = ''
                    Tailscale is a modern VPN built on top of Wireguard. It works like an
                    overlay network between the computers of your networks - using all kinds
                    of NAT traversal sorcery.
                    Everything in Tailscale is Open Source, except the GUI clients for
                    proprietary OS (Windows and macOS/iOS), and the
                    'coordination/control server'.
                    The control server works as an exchange point of Wireguard public keys for
                    the nodes in the Tailscale network. It also assigns the IP addresses of
                    the clients, creates the boundaries between each user, enables sharing
                    machines between users, and exposes the advertised routes of your nodes.
                    Headscale implements this coordination server.
                  '';
                  license = licenses.bsd3;
                  maintainers = with maintainers; [ nkje jk kradalby ];
                };
              };
          };
        }
      );
}
